HopscotchMap

Struct HopscotchMap 

pub struct HopscotchMap<K: 'static, V: 'static, S = FixedState> { /* private fields */ }
A concurrent, lock-free hash map based on Hopscotch Hashing.

Implementations

Source

impl<K, V> HopscotchMap<K, V, FixedState>
where K: Hash + Eq + Clone + 'static, V: Clone + 'static,

pub fn new() -> Self

Creates a new HopscotchMap with default capacity and hasher.

pub fn with_capacity(capacity: usize) -> Self

Creates a new HopscotchMap with the specified capacity and default hasher.

Source

impl<K, V, S> HopscotchMap<K, V, S>
where K: Hash + Eq + Clone + 'static, V: Clone + 'static, S: BuildHasher,

pub fn with_hasher(hasher: S) -> Self

Creates a new HopscotchMap with the specified hasher and default capacity.

pub fn with_capacity_and_hasher(capacity: usize, hasher: S) -> Self

Creates a new HopscotchMap with the specified capacity and hasher.

pub fn len(&self) -> usize

Returns the number of elements in the map.

pub fn is_empty(&self) -> bool

Returns true if the map contains no elements.

pub fn capacity(&self) -> usize

Returns the current capacity of the map.

pub fn get<Q>(&self, key: &Q) -> Option<V>
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Returns the value corresponding to the key.

pub fn insert(&self, key: K, value: V) -> Option<V>

Inserts a key-value pair into the map.

pub fn get_or_insert(&self, key: K, value: V) -> V

Returns the value corresponding to the key, or inserts the given value if the key is not present.

When multiple threads call this concurrently for the same key, all callers are guaranteed to receive the same value (the one visible in the map).

pub fn insert_if_absent(&self, key: K, value: V) -> Option<V>

Insert a key-value pair only if the key does not exist. Returns None if inserted, Some(existing_value) if the key already exists.

pub fn remove<Q>(&self, key: &Q) -> Option<V>
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Removes a key from the map, returning the value at the key if the key was previously in the map.

pub fn clear(&self)

Clears the map, removing all key-value pairs.

pub fn iter(&self) -> HopscotchIter<'_, K, V, S>

Returns an iterator over the map entries.

pub fn keys(&self) -> HopscotchKeys<'_, K, V, S>

Returns an iterator over the map keys.

pub fn hasher(&self) -> &S

Get the underlying hasher.